@@ -9,6 +9,7 @@ from datetime import datetime
 import asyncssh
 from asyncssh.sftp import SFTPOpUnsupported
 from fsspec.asyn import AsyncFileSystem, async_methods, sync, sync_wrapper
+from fsspec.utils import infer_storage_options
 
 from sshfs.file import SSHFile
 from sshfs.pools import SFTPSoftChannelPool
@@ -73,6 +74,19 @@ class SSHFileSystem(AsyncFileSystem):
             self, sync, self.loop, self._finalize, self._pool, self._stack
         )
 
+    @classmethod
+    def _strip_protocol(cls, path):
+        # Remove components such as host and username from path.
+        inferred_path = infer_storage_options(path)["path"]
+        return super()._strip_protocol(inferred_path)
+
+    @staticmethod
+    def _get_kwargs_from_urls(urlpath):
+        out = infer_storage_options(urlpath)
+        out.pop("path", None)
+        out.pop("protocol", None)
+        return out
+
     @wrap_exceptions
     async def _connect(
         self, host, pool_type, max_sftp_channels, **client_args
@@ -86,12 +100,13 @@ class SSHFileSystem(AsyncFileSystem):
 
     connect = sync_wrapper(_connect)
 
-    async def _finalize(self, pool, stack):
+    @staticmethod
+    async def _finalize(pool, stack):
         await pool.close()
 
         # If an error occurs while the SSHFile is trying to
         # open the native file, then the client might get broken
-        # due to partial initalization. We are just going to ignore
+        # due to partial initialization. We are just going to ignore
         # the errors that arises on the finalization layer
         with suppress(BrokenPipeError):
             await stack.aclose()
@@ -123,6 +138,7 @@ class SSHFileSystem(AsyncFileSystem):
 
     @wrap_exceptions
     async def _info(self, path, **kwargs):
+        path = self._strip_protocol(path)
         async with self._pool.get() as channel:
             attributes = await channel.stat(path)
 
@@ -133,6 +149,13 @@ class SSHFileSystem(AsyncFileSystem):
         info["name"] = path
         return info
 
+    @wrap_exceptions
+    async def _modified(self, path: str, **kwargs) -> datetime:
+        path_info = await self._info(path)
+        return path_info["mtime"]
+
+    modified = sync_wrapper(_modified)
+
     @wrap_exceptions
     async def _mv(self, lpath, rpath, **kwargs):
         async with self._pool.get() as channel:
@@ -302,3 +325,23 @@ class SSHFileSystem(AsyncFileSystem):
 
     def _open(self, path, *args, **kwargs):
         return SSHFile(self, path, *args, **kwargs)
+
+    @wrap_exceptions
+    async def _cat_file(self, path, **kwargs):
+        """Asynchronously fetch the contents of a file"""
+        async with self._pool.get() as channel:
+            async with channel.open(path, "rb") as f:
+                return await f.read()
+
+    @wrap_exceptions
+    async def _pipe_file(self, path, data, chunksize=50 * 2**20, **kwargs):
+        """Asynchronously writes the given data to a remote file in chunks."""
+        await self._makedirs(self._parent(path), exist_ok=True)
+
+        async with self._pool.get() as channel:
+            async with channel.open(path, "wb") as f:
+                for i in range(0, len(data), chunksize):
+                    chunk = data[i : i + chunksize]
+                    await f.write(chunk)
+
+        self.invalidate_cache(path)
