@@ -4,11 +4,13 @@ import secrets
 import tempfile
 import warnings
 from concurrent import futures
-from datetime import datetime, timedelta
+from datetime import datetime
 from pathlib import Path
 
+import fsspec
 import pytest
 from asyncssh.sftp import SFTPFailure
+from importlib_metadata import entry_points
 
 from sshfs import SSHFileSystem
 
@@ -71,6 +73,33 @@ def strip_keys(info):
         info.pop(key, None)
 
 
+def test_fsspec_registration(ssh_server):
+    for ep in list(entry_points(group="fsspec.specs")):
+        fs = fsspec.filesystem(
+            ep.name,
+            host=ssh_server.host,
+            port=ssh_server.port,
+            username="user",
+            client_keys=[USERS["user"]],
+        )
+        assert isinstance(fs, SSHFileSystem)
+
+
+def test_fsspec_url_parsing(ssh_server, remote_dir, user="user"):
+    for ep in list(entry_points(group="fsspec.specs")):
+        url = f"{ep.name}://{user}@{ssh_server.host}:{ssh_server.port}/{remote_dir}/file"
+        with fsspec.open(url, "w", client_keys=[USERS[user]]) as file:
+            # Check the underlying file system.
+            file_fs = file.buffer.fs
+            assert isinstance(file_fs, SSHFileSystem)
+            assert file_fs.storage_options == {
+                "host": ssh_server.host,
+                "port": ssh_server.port,
+                "username": user,
+                "client_keys": [USERS[user]],
+            }
+
+
 def test_info(fs, remote_dir):
     fs.touch(remote_dir + "/a.txt")
     details = fs.info(remote_dir + "/a.txt")
@@ -267,7 +296,6 @@ def test_concurrent_operations(fs, remote_dir):
             return stream.read()
 
     with futures.ThreadPoolExecutor() as executor:
-
         write_futures, _ = futures.wait(
             [executor.submit(create_random_file) for _ in range(64)],
             return_when=futures.ALL_COMPLETED,
@@ -309,3 +337,38 @@ def test_concurrency_for_raw_commands(fs, remote_dir):
         ]
         for future in futures.as_completed(cp_futures):
             future.result()
+
+
+def test_modified(fs, remote_dir):
+    modified = fs.modified(remote_dir)
+    assert isinstance(modified, datetime)
+
+
+def test_cat_file_sync(fs, remote_dir):
+    # Define the content to write to the test file
+    test_content = b"Test content for cat_file"
+    test_file_path = remote_dir + "/test_file.txt"
+
+    # Write content to the file synchronously
+    with open(test_file_path, "wb") as f:
+        f.write(test_content)
+
+    # Use the cat_file method to read the content back synchronously
+    read_content = fs.cat_file(test_file_path)
+
+    # Verify the content read is the same as the content written
+    assert (
+        read_content == test_content
+    ), "The content read from the file does not match the content written."
+
+
+def test_pipe_file(fs, remote_dir):
+    test_data = b"Test data for pipe_file" * (2**20)  # 1 MB of test data
+    test_file_path = remote_dir + "/test_pipe_file.txt"
+
+    fs.pipe_file(test_file_path, test_data)
+
+    with fs.open(test_file_path, "rb") as f:
+        assert (
+            f.read() == test_data
+        ), "The data read from the file does not match the data written."
